==> hs-postgresql-libpq-0.8.2.2p0.tgz: lib/ghc/postgresql-libpq-0.8.2.2/register.sh <==
#!/bin/sh
echo 'name: postgresql-libpq
version: 0.8.2.2
id: postgresql-libpq-0.8.2.2-9725e44a86662267328b5c4ddb0ca6e6

license: BSD3
copyright: (c) 2010 Grant Monroe
           (c) 2011 Leon P Smith
maintainer: Leon P Smith <leon@melding-monads.com>
stability:
homepage: http://github.com/lpsmith/postgresql-libpq
package-url:
synopsis: low-level binding to libpq
description: This is a binding to libpq: the C application
             programmer'\''s interface to PostgreSQL. libpq is a
             set of library functions that allow client
             programs to pass queries to the PostgreSQL
             backend server and to receive the results of
             these queries.
category: Database
author: Grant Monroe, Leon P Smith, Joey Adams
pkgpath: databases/hs-postgresql-libpq
exposed: True
exposed-modules: Database.PostgreSQL.LibPQ
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/postgresql-libpq-0.8.2.2
library-dirs: /usr/local/lib/ghc/postgresql-libpq-0.8.2.2
              /usr/local/lib
hs-libraries: HSpostgresql-libpq-0.8.2.2
extra-libraries: pq crypto ssl com_err asn1 krb5 wind roken
                 heimbase
extra-ghci-libraries:
include-dirs: /usr/local/include/postgresql
includes:
depends: base-4.6.0.1-03845c6da2a0b3b4d0d49cc26c0cd3c0
         bytestring-0.10.0.2-9e8b487747800a4255d6ff7915c5210f
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-postgresql-libpq-0.8.2.2/html/postgresql-libpq.haddock
haddock-html: /usr/local/share/doc/hs-postgresql-libpq-0.8.2.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> hs-postgresql-libpq-0.8.2.5.tgz: lib/ghc/postgresql-libpq-0.8.2.5/register.sh <==
#!/bin/sh
echo 'name: postgresql-libpq
version: 0.8.2.5
id: postgresql-libpq-0.8.2.5-deac34083c872f6845400600404988d2

license: BSD3
copyright: (c) 2010 Grant Monroe
           (c) 2011 Leon P Smith
maintainer: Leon P Smith <leon@melding-monads.com>
stability:
homepage: http://github.com/lpsmith/postgresql-libpq
package-url:
synopsis: low-level binding to libpq
description: This is a binding to libpq: the C application
             programmer'\''s interface to PostgreSQL. libpq is a
             set of library functions that allow client
             programs to pass queries to the PostgreSQL
             backend server and to receive the results of
             these queries.
category: Database
author: Grant Monroe, Leon P Smith, Joey Adams
pkgpath: databases/hs-postgresql-libpq
exposed: True
exposed-modules: Database.PostgreSQL.LibPQ
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/postgresql-libpq-0.8.2.5
library-dirs: /usr/local/lib/ghc/postgresql-libpq-0.8.2.5
              /usr/local/lib
hs-libraries: HSpostgresql-libpq-0.8.2.5
extra-libraries: crypto ssl com_err asn1 krb5 wind roken heimbase
                 pq
extra-ghci-libraries:
include-dirs: /usr/local/include/postgresql
includes:
depends: base-4.6.0.1-d435272bc8de1d17f3a0aacfbd562dbe
         bytestring-0.10.0.2-f858e0cb19bca2e9549882fc8424f656
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-postgresql-libpq-0.8.2.5/html/postgresql-libpq.haddock
haddock-html: /usr/local/share/doc/hs-postgresql-libpq-0.8.2.5/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
